@@ -1,9 +1,9 @@
 import os
 import boto3
-import utils
 import logging
 import botocore
 import tempfile
+from . import utils
 from pathlib import Path
 
 # declare the logging object
